@@ -222,12 +222,9 @@ public class JavaEngine extends AbstractScriptEngine {
 				for (int i = 0; i < urls.length; i++)
 					urls[i] =
 						new URL("file:" + paths[i] + (paths[i].endsWith(".jar") ? "" : "/"));
-				URLClassLoader classLoader =
-					new URLClassLoader(urls, Thread.currentThread()
-						.getContextClassLoader());
 
-				// needed for annotation processing
-				Thread.currentThread().setContextClassLoader(classLoader);
+				final URLClassLoader classLoader =  new URLClassLoader(urls, Thread.currentThread()
+						.getContextClassLoader());
 
 				// load main class
 				return classLoader.loadClass(mainClass);
@@ -473,8 +470,8 @@ public class JavaEngine extends AbstractScriptEngine {
 		 * @return the created {@link BuildEnvironment}.
 		 */
 		private BuildEnvironment createBuildEnvironment() {
-			boolean verbose = "true".equals(get("verbose"));
-			boolean debug = "true".equals(get("debug"));
+			boolean verbose = "true".equals(get("verbose")) || log().isInfo();
+			boolean debug = "true".equals(get("debug")) || log().isDebug();
 			return new BuildEnvironment(err, true, verbose, debug);
 		}
 
@@ -553,8 +550,9 @@ public class JavaEngine extends AbstractScriptEngine {
 			Pattern.compile(".*public class ([a-zA-Z0-9_]*).*");
 		final BufferedReader reader = new BufferedReader(new FileReader(file));
 		for (;;) {
-			String line = reader.readLine().trim();
+			String line = reader.readLine();
 			if (line == null) break;
+			line = line.trim();
 			outerLoop:
 			while (line.startsWith("/*")) {
 				int end = line.indexOf("*/", 2);
